 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 This Reahl component includes functionality modelling user accounts,
 some simple workflow concepts and more.
